/*******************************************************************
 * Fritz Fun                                                       *
 * Created by Louis Lagendijk                                      *
 * All parts are distributed under the terms of GPLv2. See COPYING *
 *******************************************************************/

/**
 * \file menu.c
 * \brief Wrapper for he menu system (trayicon and menubar)
 */

#include <ffgtk.h>
#include <trayicon.h>
#include <menubar.h>
#include <limits.h>

int nOpenWindows = 0;

/**
 * \brief mark windos as open
 */

void markWindowOpen( int nType ) {
	nOpenWindows = nOpenWindows | ( 1 << nType );
	Debug( KERN_DEBUG, "nOpenWindows is now: %d\n", nOpenWindows );
}

/**
 * \brief Mark window as closed
 */

void markWindowClosed( int nType) {
	nOpenWindows = nOpenWindows & ( INT_MAX ^ ( 1 << nType ) );
	Debug( KERN_DEBUG, "nOpenWindows is now: %d\n", nOpenWindows );
}

bool windowIsOpen( int nType ) {
	return ( ( nOpenWindows & ( 1 << nType ) )  != 0 );
}


/**
 * \brief Initialize menu system, create menu bar and tray icon andi start tooltip thread
 */
 
void menuInit( void ) {
	trayIconInit();
#ifdef __MACOSX__
	menuBarInit();
#endif
}

/**
 * \brief recreate app menu  
 */
 
void menuRecreateAppMenu( void ) {
	trayIconRecreateAppMenu();
#ifdef __MACOSX__
	menuBarRecreateAppMenu();
#endif
}

/**
 * \brief set program icon on trayicon 
 */

void menuSetIconType( int nType ) {
	trayIconSetIconType(nType);
}

/**
 *  \brief get menu/trayicon widget
 * \return trayicon widget
 */

GtkStatusIcon *menuGetIcon( void ) {
	return getTrayIcon();
}
